#
# spec file for package compcache
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild
# nodebuginfo

%if %suse_version <= 1120
%define need_kmp	1
%else
%define need_kmp	0
%endif

%if %suse_version <= 1130
%define need_rzsctl	1
%else
%define need_rzsctl	0
%endif

Name:           compcache
%if %need_kmp
BuildRequires:  kernel-source kernel-syms module-init-tools
%endif
License:        GPLv2
Group:          System/Kernel
Version:        0.6.2
Release:        4.5.2
Summary:        Compressed RAM based swap device
Source0:        compcache-%{version}.tar.bz2
Source1:        sysconfig.compcache
Source2:        boot.compcache
Patch:          compcache-rzscontrol-cflags.diff
Patch1:         ramzswap-kernel-build-fix.diff
Url:            http://code.google.com/p/compcache/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %fillup_prereq
%if %need_kmp
Requires:       compcache-kmp
%suse_kernel_module_package -n %{name} kdump um
%else
%if !%need_rzsctl
BuildArch:      noarch
%endif
%endif

%description
The compcache is a RAM-based block device acting as a swap disk. This
can effectively increase the available memory on your machine by
virtually swapping pages into the compressed memory.

This package contains the boot script for loading/unloading the
modules. The modules are contained in compcache-kmp packages.

%if %need_kmp

%package KMP
License:        GPLv2
Summary:        Kernel module for compressed RAM based swap device
Group:          System/Kernel

%description KMP
The compcache is a RAM-based block device acting as a swap disk. This
can effectively increase the available memory on your machine by
virtually swapping pages into the compressed memory.

This package contains the kernel module for compcache.
%endif

%prep
%setup -q
%patch -p1
%patch1 -p1

%build
%if %need_kmp
for flavor in %flavors_to_build; do
	rm -rf obj/$flavor
	mkdir -p obj/$flavor
	cp -al *.[ch] Makefile sub-projects obj/$flavor
	KERNEL_OBJ="/usr/src/linux-obj/%_target_cpu/$flavor"
	make -C ${KERNEL_OBJ} M=$PWD/obj/$flavor modules
done
%endif
%if %need_rzsctl
make -C sub-projects/rzscontrol
%endif

%install
%if %need_kmp
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=updates
for flavor in %flavors_to_build; do
	KERNEL_OBJ="/usr/src/linux-obj/%_target_cpu/$flavor"
	make -C ${KERNEL_OBJ} M=$PWD/obj/$flavor modules_install
done
%endif
%if %need_rzsctl
mkdir -p $RPM_BUILD_ROOT/usr/sbin
install -c -m 0755 sub-projects/rzscontrol/rzscontrol $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
install -c -m 0644 sub-projects/rzscontrol/man/*.1 $RPM_BUILD_ROOT/%{_mandir}/man1
%endif
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -c -m 0644 %{SOURCE1} $RPM_BUILD_ROOT/var/adm/fillup-templates
mkdir -p $RPM_BUILD_ROOT/etc/init.d
install -c -m 0755 %{SOURCE2} $RPM_BUILD_ROOT/etc/init.d/

%post
%{fillup_only}

%preun
%stop_on_removal

%postun
%{insserv_cleanup}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%if %need_rzsctl
/usr/sbin/*
%{_mandir}/man?/*
%endif
/etc/init.d/boot.compcache
/var/adm/fillup-templates/sysconfig.compcache
%doc README Changelog

%changelog
* Mon Mar 21 2011 tiwai@suse.de
- Fix init script for 11.4 to work with empty $COMPCACHE_SIZE_KB
  (bnc#681048)
* Thu Jan 13 2011 tiwai@suse.de
- fix some typos in init script
* Tue Jan 11 2011 tiwai@suse.de
- updated to compcache-0.6.2: see ChangeLog for details;
  this fixes the incompatible statics ioctl for oS 11.3
  (bnc#647345)
- improved / fixed init and sysconfig files (bnc#661993)
- adapted init script for 11.4 ramz driver; rzscontrol is no
  longer used for zram driver; package contains only scripts
* Wed May 12 2010 tiwai@suse.de
- don't build KMPs for openSUSE 11.3 or later as the kernel
  already supports ramzswap (bnc#604610)
* Wed Apr 21 2010 coolo@novell.com
- include header for kzalloc
* Tue Mar  9 2010 death_knight@gamebox.net
- additional ramzswap devices for SMP CPU machines.
* Tue Dec 29 2009 coolo@novell.com
- actually compile the binaries to be portable
* Tue Nov 24 2009 tiwai@suse.de
- yet another fixes for older kernels
* Mon Nov 23 2009 tiwai@suse.de
- fix builds with various kernel versions
* Mon Nov 23 2009 tiwai@suse.de
- updated to version 0.6; see ChangeLog for details
* Mon Aug  3 2009 tiwai@suse.de
- fix build with 2.6.31 kernel
* Fri May  8 2009 tiwai@suse.de
- disable build on 10.3 and older, removed the test patch
- fix boot script to match with ramzswap
* Thu May  7 2009 tiwai@suse.de
- fix build with 10.3 kernel
* Thu May  7 2009 tiwai@suse.de
- clean up obsolete patch
* Thu May  7 2009 cyberorg@opensuse.org
- Update to 0.5.2
* Mon Nov  3 2008 tiwai@suse.de
- fixed init script
* Thu Oct 23 2008 tiwai@suse.de
- initial version: 0.4
